# Test Coverage Report

Generated: Mon 2014-08-04 18:55 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 294 | 265 | 29 | 100.0%
user_media.__init__ | 1 | 1 | 0 | 100.0%
user_media.forms | 51 | 47 | 4 | 100.0%
user_media.models | 45 | 35 | 10 | 100.0%
user_media.processors | 4 | 4 | 0 | 100.0%
user_media.views | 193 | 178 | 15 | 100.0%

Excluded packages and modules
Error packages and modules